
Overview
========

Python library for the PagerDuty service API.

http://www.pagerduty.com/docs/api/api-documentation


## Build

Uses [Hatch][hatch].


## Author Information

[Mészáros Máté Róbert][mrmeszaros]. Heavily based on [Samuel Stauffer][samuel]'s `pagerduty`. Forked from DataDog Inc.'s archived [clone][datadog].


[hatch]: https://hatch.pypa.io/latest/
[datadog]: https://github.com/DataDog/python-pagerdutyg
[mrmeszaros]: http://github.com/mrmeszaros
[samuel]: http://github.com/samuel
